@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: ppplog.c,v 1.11 2001/03/15 18:59:57 berberic Exp berberic $ 
+ *  $Id: ppplog.c,v 1.12 2001/03/20 17:34:51 berberic Exp berberic $ 
  */
 
 
@@ -69,7 +69,7 @@ static struct vector *init_vector(struct vector *v, int a)
 }
 
 static int add_to_vector(struct vector *v, char *p, unsigned long a, 
-			 unsigned long in, unsigned long out)
+			 unsigned long out, unsigned long in)
 {
   int i;
 
@@ -288,12 +288,12 @@ int main(int argc, char **argv)
   
   printf("Date       Start       End          Provider    Connect");
   if (transfer)
-    printf("     In    Out");
+    printf("   Send   Rcvd");
   printf("\n");
 
   while(8==(res = fscanf(data, "%10s %8s %4s %*s %20s %20s %ld %ld %ld\n", 
 		  date, endtime, zone, provider, interface, 
-		  &connect, &in, &out))) {
+		  &connect, &out, &in))) {
 
     /* nice print of connecttime */
     sec_to_string(connect, s1, 20);
@@ -318,7 +318,7 @@ int main(int argc, char **argv)
     }
 
     /* sum up the connect-times */
-    if(!add_to_vector(&provider_sum, provider, connect, in ,out)) {
+    if(!add_to_vector(&provider_sum, provider, connect, out, in)) {
       fprintf(stderr, "Can't re-allocate vector ?!\n");
       return 2;
     }
@@ -329,7 +329,7 @@ int main(int argc, char **argv)
     /* print a line of the report */
     printf("%10s %8s -- %8s %12s %10s", s2, starts , endtime,  provider, s1);
     if (transfer) 
-      print_transfer(in, out);
+      print_transfer(out, in);
     printf("\n");
   }
 
@@ -349,7 +349,7 @@ int main(int argc, char **argv)
     printf("Sum                             %12s %10s", 
 	   provider_sum.data[i].provider, s1);
     if (transfer) 
-      print_transfer(provider_sum.data[i].insum, provider_sum.data[i].outsum);
+      print_transfer(provider_sum.data[i].outsum, provider_sum.data[i].insum);
     printf("\n");
       
   }
@@ -365,7 +365,7 @@ int main(int argc, char **argv)
   printf("Sum                             %12s %10s", "total", s1);
 
   if (transfer) 
-    print_transfer(insum, outsum);
+    print_transfer(outsum, insum);
   printf("\n");
   
   return 0;
